/* $Id: errno.h,v 1.4 2000/05/26 23:04:23 becka Exp $
******************************************************************************

   KGIcon - device file definitions

   Copyright (C) 1995	Andreas Beck	[becka@ggi-project.org]
   Copyright (C) 1995	Steffen Seeger	[seeger@ggi-project.org]

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

#ifndef _KGI_ERRNO_H
#define _KGI_ERRNO_H

/*\
|*|	Error codes
\*/

enum kgi_subsystems
{
	DRIVER,		MONITOR,	RAMDAC,		CLOCK,
	CHIPSET,	ACCEL,		VIDIO,		LIB,
	KGI_NR_SUBSYSTEMS = 0xF
};

enum kgi_nosup_codes 
{ 	/* Methods */
	AVM_IOCTL = 0x00,	/* ioctl is ok - use it */
	AVM_MMAP  = 0x01,	/* use mmap */
	AVM_LOWER = 0x02,	/* use lower level functions */
	AVM_CANT  = 0x03,	/* no support (like setpal in 16M) */
	AVM_MASK  = 0x0f,
	/* Expire-times */
	AVE_TEST  = 0x00,	/* Test it ... */
	AVE_NOW   = 0x00,	/* Retry next time */
	AVE_MODE  = 0x10,	/* reset when mode changes */
	AVE_ALWAYS= 0x20,	/* Always do it this way   */
	AVE_MASK  = 0xf0 };

enum kgi_error_code
{
	OK		= 0x00000000,	/* request done			*/

	UNKNOWN,		/* unspecified error			*/
	BOGUS,			/* request doesn't make sense		*/
	FAILED,			/* operation requested not possible	*/

	MODE_CHECK	= 0x00000100,	/* mode check failed,		*/

	CLK_LOW_LIMIT,		/* clock rate out of lower bound	*/
	CLK_HIGH_LIMIT,		/* clock rate out of upper bound	*/
	CLK_LIMIT,		/* clock rate out of range		*/
	RESOLUTION_LOW,		/* resolution too bad			*/
	RESOLUTION_HIGH,	/* resolution too high			*/

	NOSUP		= 0x00000200,			/* "no support" codes	*/
	NOSUP_NOW_MMAP	= NOSUP|AVE_NOW|AVM_MMAP,	/* can't do this right now. Use MMAP instead */
	NOSUP_NOW_LOWER	= NOSUP|AVE_NOW|AVM_LOWER,	/* can't do this right now. Use simpler commands */
	NOSUP_NOW_CANT	= NOSUP|AVE_NOW|AVM_CANT,	/* can't do it now. */
	NOSUP_MODE_MMAP	= NOSUP|AVE_MODE|AVM_MMAP,	/* can't do this in this mode. Use MMAP */
	NOSUP_MODE_LOWER= NOSUP|AVE_MODE|AVM_LOWER,	/* can't do this in this mode. Use simpler commands */
	NOSUP_MODE_CANT	= NOSUP|AVE_MODE|AVM_CANT,	/* impossible in this mode. */
	NOSUP_ALWAYS_MMAP = NOSUP|AVE_ALWAYS|AVM_MMAP,	/* not supported. Use MMAP */
	NOSUP_ALWAYS_LOWER= NOSUP|AVE_ALWAYS|AVM_LOWER,	/* not supported. Use simpler commands */
	NOSUP_ALWAYS_CANT = NOSUP|AVE_ALWAYS|AVM_CANT,	/* not supported at all. */

	NOSUP_MASK       = 0x00ffff00	/* these bits must match NOSUP,if it is a NOSUP-type error */
};

#define	E(subsystem, code)	((subsystem << 24) | code)
#define	ESUBSYSTEM(err)		(err >> 24)
#define	ECODE(err)		(err & 0x00FFFFFF)

#define	EOK	E(DRIVER, OK)

#endif	/* #ifdef _KGI_ERRNO_H */
